/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("dojo.dependency");

dojo.require("dojox.collections.Dictionary");
dojo.require("dojox.collections.ArrayList");

(function(){
	var _addDependencyGraphParams = {
		indexGraph: new dojox.collections.Dictionary(),
		uriGraph: new dojox.collections.Dictionary(),
		moduleGraph: new dojox.collections.Dictionary(),
		webBundleMap: new dojox.collections.Dictionary()
	};
	
	for (var param in _addDependencyGraphParams) {
		dojo.dependency[param] = _addDependencyGraphParams[param];
	}
	
	var data = net.jazz.ajax.core.runtime._dependencyGraphData;
	
	for (var i = 0; i < data.wb.length; i++) {
		var webBundle = data.wb[i];
		dojo.dependency.webBundleMap.add(webBundle.i, webBundle.v);
	}
	
	for (var i = 0; i < data.j.length; i++) {
		var jsModule = data.j[i];
		dojo.dependency.indexGraph.add(jsModule.i, jsModule);
		dojo.dependency.uriGraph.add(jsModule.u, jsModule);
		dojo.dependency.moduleGraph.add(jsModule.m, jsModule);
	}
})();

dojo.dependency.getDependencyUri = function(uri) {
	var jsModule = this.uriGraph.item(uri);
	if (jsModule != undefined) {
		var dependencyUri = dojo.dependency.findDependency(jsModule, new dojox.collections.ArrayList());
		var version = dojo.dependency.resolveVersion(jsModule, new dojox.collections.ArrayList(), new dojox.collections.ArrayList())
		if (dependencyUri == "") {
			return dependencyUri;
		}
		else {
			return dependencyUri = "?ver=" + version + "&loc=" + dojo.locale + "&dep=" + dependencyUri;
		} 
	}
	else {
		if (window.location.search.indexOf("debug=true") != -1) {
			return "?debug=true";
		}
		else {
			return "";
		}			
	}	
}
	
dojo.dependency.setDependencyLoaded = function(module) {
	var jsModule =  this.moduleGraph.item(module);
	if (jsModule != undefined) {
		jsModule.l = true;
	}
}

dojo.dependency.findDependency = function(jsModule, seen) {
	var dependencyUri = "";
	for (var i = 0; i < jsModule.d.length; i++) {
		var dependencyModule =  this.indexGraph.item(jsModule.d[i]);
		if (dependencyModule != undefined && dependencyModule.l == false && seen.contains(jsModule.d[i]) == false) {
			seen.add(jsModule.d[i]);
			dependencyUri += dojo.dependency.findDependency(dependencyModule, seen);
			dependencyUri += jsModule.d[i];
		}	
	}
	return dependencyUri;
}

dojo.dependency.resolveVersion = function(jsModule, seen, versionSeen) {
	var version = 0;
	if (seen.contains(jsModule.i) == false) {
		seen.add(jsModule.i);
		if (versionSeen.contains(jsModule.b) == false) {
			version += this.webBundleMap.item(jsModule.b);
			versionSeen.add(jsModule.b);
		}
	}
	for (var i = 0; i < jsModule.d.length; i++) {
		var dependencyModule =  this.indexGraph.item(jsModule.d[i]);
		if (dependencyModule != undefined && dependencyModule.l == false && seen.contains(jsModule.d[i]) == false) {
			version += dojo.dependency.resolveVersion(dependencyModule, seen, versionSeen);
		}	
	}
	return version;
}