/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("com.ibm.team.repository.web.ui.internal.admin.server.ConfigureFeedSettings");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojox.data.dom");

dojo.require("net.jazz.ajax.toolbox.lang.internal.Lang");
dojo.require("com.ibm.team.repository.web.client.internal.AdminClient");
dojo.require("com.ibm.team.repository.web.client.internal.RepositoryClient");
dojo.require("com.ibm.team.repository.web.client.internal.ServerStatusClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.ui.internal.admin.server.ServerPropertyService");
dojo.require("com.ibm.team.repository.web.ui.internal.admin.server.ConfigUtility");
dojo.require("dojo.i18n");

dojo.requireLocalization("com.ibm.team.repository.web.ui.internal.admin.server", "ConfigurePageMessages");



(function() {

var ServerPropertyService = com.ibm.team.repository.web.ui.internal.admin.server.ServerPropertyService;
var ServerStatusClient = com.ibm.team.repository.web.client.internal.ServerStatusClient;
var ServiceResponseHandler = com.ibm.team.repository.web.transport.ServiceResponseHandler;
var ConfigUtility = com.ibm.team.repository.web.ui.internal.admin.server.ConfigUtility;

dojo.declare("com.ibm.team.repository.web.ui.internal.admin.server.ConfigureFeedSettings", [ConfigUtility, dijit._Widget, dijit._Templated], {

	templatePath: dojo.moduleUrl("com.ibm.team.repository.web", "ui/internal/admin/server/templates/Configure.html"),
	_allServices: {
		"com.ibm.team.repository.service.feed.internal.FeedService": "feedTableHeading"
	},
	_propertySortOrder: [
		"feed.render.scheme",
		"feed.query.maxentries",
		"feed.entrycache.maxlifetime",
		"feed.entrycache.size"
	],

	// widget initialization
	constructor: function() {
		this.messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.internal.admin.server", "ConfigurePageMessages");
	},

	postCreate: function () {
		com.ibm.team.repository.web.ui.internal.admin.server.ConfigureFeedSettings.superclass.postCreate.apply(this);
		this.pageHeading.appendChild(document.createTextNode(this.messages.feedsHeading));
		this._initializeContent();
		this._saveButton.disabled = true;
		this._createSaveHandler(this._saveButton);
	},
	
	_initializeContent: function () {
		this._services = new Array();
		for (var serviceName in this._allServices) {
			var curService = new ServerPropertyService({
				"serviceInfo": {
					"implementationClassName": serviceName
				},
				"enableEdits": true,
				"serviceHeaderClass": ["header1"],
				"propertiesRowClass": [],
				"propertySortOrder": this._propertySortOrder,
				"customTitle": this.messages[this._allServices[serviceName]],
				"displayIn": this._configContainer
			});
			this._services.push(curService);
			this.connect(curService, "_markChanged", function () {
				this._saveButton.disabled = false;
			});
			this.connect(curService, "_checkUnchanged", function () {
				var change = false;
				for (var j=0; j < this._services.length; j++) {
					if (this._services[j]._changed) {
						change = true;
						break;
					}
				}
				if (!change) {
					this._saveButton.disabled = true;
				}
			});
		}
	},
	
	_getChanges: function () {
		var changes = {
			"changes": [],
			"properties": []
		};
		for (var i=0; i < this._services.length; i++) {
			var obj = this._services[i]._getChanges();
			changes["changes"] = changes["changes"].concat(obj["changes"]);
			changes["properties"] = changes["properties"].concat(obj["properties"]);
		}
		return changes;
	}
});

})();