/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.repository.web.ui.internal.wizard.WizardApplication");

dojo.require("net.jazz.ajax.ui._Application");
dojo.require("net.jazz.ajax.ui.PageContainer");
dojo.require("net.jazz.ajax.ui.PageList");
dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("net.jazz.ajax.ui.ProgressIndicator");
dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.client.internal.RepositoryClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.internal.ProvisionResponseHandler");
dojo.require("com.ibm.team.repository.web.client.internal.ProvisioningClient");
dojo.require("dojo.i18n");

dojo.requireLocalization("com.ibm.team.repository.web.ui.internal.wizard", "WizardApplicationMessages");

function workbenchRootNode(){
	return net.jazz.ajax.ui.PlatformUI.getWorkbench().rootNode();
}

var InitializationData      = com.ibm.team.repository.web.client.init.InitializationData;
var RepositoryClient 		= com.ibm.team.repository.web.client.internal.RepositoryClient;
var SRH	= com.ibm.team.repository.web.transport.ServiceResponseHandler
var ProvisioningClient = com.ibm.team.repository.web.client.internal.ProvisioningClient;
var ProvisionResponseHandler = com.ibm.team.repository.web.transport.internal.ProvisionResponseHandler;
var X_AUTH_MSG					= "X-com-ibm-team-repository-web-auth-msg";


dojo.declare("com.ibm.team.repository.web.ui.internal.wizard.WizardApplication", net.jazz.ajax.ui._Application, {
	
	constructor: function() {
		this.messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.internal.wizard", "WizardApplicationMessages");
	},

	init: function() {
		// fetch quick secured command to require ADMIN auth.  
		// can't use Util.userIsAdmin since it's false for everyone if DB is down
		var prh = new ProvisionResponseHandler(this, "authRequestPassed", "authRequestFailed");
		ProvisioningClient.isRepositoryAvailable(prh);		
	},	

	_startApp: function () {
		this._createUI();
		this.setName(this.messages.setupName);
		this.start();
	},
	
	_createUI: function() {		
		dojo.addClass(workbenchRootNode(), "com-ibm-team-repository-web-setup-RootNode");
		
		// create the page container and append it to the document body
		var pageArea = new net.jazz.ajax.ui.PageContainer();
		workbenchRootNode().appendChild(pageArea.domNode);
	},
	
	authRequestPassed: function() {
		RepositoryClient.getInitializationData(new SRH(this, "_handleInitData", "_fetchInitDataFailed"));
	},
	
	authRequestFailed: function(errorObject) {
		dojo.setObject("com.ibm.team.repository.web.noAdminAuth", "not authorized");
		RepositoryClient.getInitializationData(new SRH(this, "_handleInitData", "_fetchInitDataFailed"));
	}, 
	
		
	_handleInitData: function(initData) {
		InitializationData._load(initData);
		// handle case where there is no DB so contributor isn't in init data
		if (InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer") != null) {
			dojo.setObject("com.ibm.team.repository.web.client.internal.AUTHENTICATED_CONTRIBUTOR", InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer").currentContributor);
		}
		
		// store the license behavior in global vars
		if (InitializationData.get("com.ibm.team.repository.service.assertLicenseInitializer") != null) {
			var licenseBehavior = InitializationData.get("com.ibm.team.repository.service.assertLicenseInitializer");
			for (var propName in licenseBehavior) {
				var propVal = licenseBehavior[propName];
				dojo.setObject(propName, propVal);
				//alert(propName + ": " + propVal);
			}		
		}
		this._startApp();
	},
	
	_fetchInitDataFailed: function(errorObject) {	
		this._fetchAuthUserId();
	},
	
	// _fetchAuthUserId COPIED from AdminApp for 1.0.1.1 defect 60691.  
	// To be refactored into common code between WizardApplication.js and AdminApplication.js in 2.0	
	// ===
	// Fetch user from whoami and store in common object.  Used when initdata isn't available either
	// because repo is down or the user doesn't have access to initdata 
	_fetchAuthUserId: function () {
		var bindArgs= {
	        url: net.jazz.ajax._contextRoot + "/auth/whoami",
	        content: { },
			handleAs: "json",
			headers: { },
			handle: dojo.hitch(this, function(response, ioArgs){
				if (response instanceof Error) {
					var errorObj= {
						status: ioArgs.xhr.status
					};
					// format detailed message (unescape URI-encoding formatting, remove leading dashes, and trim whitespace)
					errorObj.message= dojo.trim(unescape(ioArgs.xhr.statusText).replace(/\+/g, " ").replace(/^(-*)/g, ""));
					serviceResponseHandler.doErrorCallback(errorObj);
				}
				else {
					var testAuth = ioArgs.xhr.getResponseHeader(X_AUTH_MSG);
					if (testAuth) {
						dojo.setObject("com.ibm.team.repository.web.client.internal.AUTHENTICATED_USERID", testAuth);
					}
				}
				this._startApp();
	        })
	    };
	    dojo.xhrGet(bindArgs);
	}
	
});

})();